from __future__ import absolute_import, unicode_literals

from .document_forms import *  # NOQA
from .document_page_forms import *  # NOQA
from .document_type_forms import *  # NOQA
from .document_version_forms import *  # NOQA
