{% extends 'appearance/base_plain.html' %}

{% load i18n %}
{% load static %}

{% load common_tags %}

{% block base_title %}{% trans 'Password reset' %}{% endblock %}

{% block project_name %}{% endblock %}

{% block content_plain %}
    <div class="row">
        <div class="col-xs-10 col-xs-offset-1 col-sm-8 col-sm-offset-2 col-md-6 col-md-offset-3 col-lg-4 col-lg-offset-4">
            <div class="alert alert-success" role="alert">{% trans 'Password reset complete! Click the link below to login.' %}</div>

            <div class="text-center"><a class="btn btn-primary" href="{% url 'authentication:logout_view' %}">{% trans 'Login page' %}</a></div>
        </div>
    </div>

{% endblock content_plain %}
