from __future__ import absolute_import, unicode_literals

from mayan.apps.appearance.classes import Icon

icon_source_column_help_text = Icon(
    driver_name='fontawesome', symbol='question'
)
icon_source_column_help_text = Icon(
    driver_name='fontawesomecss', css_classes='far fa-question-circle'
)
