from __future__ import unicode_literals

CONFIGURATION_FILENAME = 'config.yml'
CONFIGURATION_LAST_GOOD_FILENAME = 'config_backup.yml'
NAMESPACE_VERSION_INITIAL = '0001'
SMART_SETTINGS_NAMESPACES_NAME = 'SMART_SETTINGS_NAMESPACES'
