from __future__ import absolute_import, unicode_literals

from mayan.apps.appearance.classes import Icon

icon_document_send = Icon(
    driver_name='fontawesome', symbol='envelope'
)
icon_document_send_link = Icon(
    driver_name='fontawesome', symbol='envelope'
)
icon_document_multiple_send = Icon(
    driver_name='fontawesome', symbol='envelope'
)
icon_document_multiple_send_link = Icon(
    driver_name='fontawesome', symbol='envelope'
)
icon_mail_document_submit = Icon(
    driver_name='fontawesome', symbol='envelope'
)
icon_system_mailer_error_log = Icon(
    driver_name='fontawesome', symbol='envelope'
)
icon_user_mailer_create = Icon(
    driver_name='fontawesome-dual', primary_symbol='envelope',
    secondary_symbol='plus'
)

icon_user_mailer_delete = Icon(driver_name='fontawesome', symbol='times')
icon_user_mailer_edit = Icon(driver_name='fontawesome', symbol='pencil-alt')
icon_user_mailer_list = Icon(driver_name='fontawesome', symbol='envelope')
icon_user_mailer_setup = Icon(driver_name='fontawesome', symbol='envelope')
icon_user_mailer_test = Icon(driver_name='fontawesome', symbol='play')
