from __future__ import absolute_import, unicode_literals

from mayan.apps.appearance.classes import Icon

icon_document_content = Icon(driver_name='fontawesome', symbol='font')
icon_document_content_delete = Icon(
    driver_name='fontawesome-dual',
    primary_symbol='font',
    secondary_symbol='minus'
)
icon_document_parsing_errors_list = Icon(
    driver_name='fontawesome', symbol='font'
)
icon_document_content_download = Icon(
    driver_name='fontawesome', symbol='font'
)
icon_document_multiple_submit = Icon(
    driver_name='fontawesome', symbol='font'
)
icon_document_submit = Icon(
    driver_name='fontawesome', symbol='font'
)
icon_document_type_parsing_settings = Icon(
    driver_name='fontawesome', symbol='font'
)
icon_document_type_submit = Icon(
    driver_name='fontawesome', symbol='font'
)
icon_link_error_list = Icon(
    driver_name='fontawesome', symbol='font'
)
