from __future__ import unicode_literals

TEST_CASE_ROLE_LABEL = 'test case role label'
TEST_INVALID_PERMISSION_NAMESPACE_NAME = 'invalid namespace'
TEST_INVALID_PERMISSION_NAME = 'invalid name'
TEST_PERMISSION_NAMESPACE_LABEL = 'test permission namespace label'
TEST_PERMISSION_NAMESPACE_NAME = 'test_permission_namespace_name'
TEST_PERMISSION_LABEL = 'test permission name label'
TEST_PERMISSION_NAME = '{}.{}'.format(
    TEST_PERMISSION_NAMESPACE_NAME, 'test_permission_name'
)
TEST_PERMISSION_NAMESPACE_LABEL_2 = 'test permission namespace label 2'
TEST_PERMISSION_NAMESPACE_NAME_2 = 'test_permission_namespace_name_2'
TEST_PERMISSION_LABEL_2 = 'test permission name label 2'
TEST_PERMISSION_NAME_2 = '{}.{}'.format(
    TEST_PERMISSION_NAMESPACE_NAME_2, 'test_permission_name'
)
TEST_ROLE_LABEL = 'test role label'
TEST_ROLE_LABEL_EDITED = 'test role label edited'
