from __future__ import absolute_import, unicode_literals

from mayan.apps.appearance.classes import Icon

icon_logout = Icon(driver_name='fontawesome', symbol='sign-out-alt')
icon_password_change = Icon(driver_name='fontawesome', symbol='key')
