from __future__ import absolute_import, unicode_literals

from mayan.apps.appearance.classes import Icon

icon_document_create_multiple = Icon(
    driver_name='fontawesome', symbol='upload'
)
icon_document_version_upload = Icon(
    driver_name='fontawesome', symbol='upload'
)
icon_log = Icon(driver_name='fontawesome', symbol='exclamation-triangle')
icon_setup_sources = Icon(driver_name='fontawesome', symbol='upload')
icon_setup_source_check_now = Icon(driver_name='fontawesome', symbol='check')
icon_setup_source_delete = Icon(driver_name='fontawesome', symbol='times')
icon_setup_source_edit = Icon(driver_name='fontawesome', symbol='pencil-alt')
icon_source_create = Icon(
    driver_name='fontawesome-dual', primary_symbol='upload',
    secondary_symbol='plus'
)
icon_source_list = Icon(driver_name='fontawesome', symbol='upload')
icon_staging_folder = Icon(driver_name='fontawesome', symbol='folder')
icon_staging_folder_file = Icon(driver_name='fontawesome', symbol='file')
icon_staging_file_delete = Icon(driver_name='fontawesome', symbol='times')
icon_upload_view_link = Icon(driver_name='fontawesome', symbol='upload')
icon_wizard_submit = Icon(driver_name='fontawesome', symbol='arrow-right')
