from __future__ import absolute_import, unicode_literals

from mayan.apps.appearance.classes import Icon

icon_document_submit = Icon(
    driver_name='fontawesome', symbol='chess-board'
)
icon_document_multiple_submit = Icon(
    driver_name='fontawesome', symbol='chess-board'
)
icon_file_metadata = Icon(
    driver_name='fontawesome', symbol='chess-board'
)
