from __future__ import unicode_literals

TEST_CACHE_LABEL = 'test cache label'
TEST_CACHE_MAXIMUM_SIZE = 2 * 2 ** 20  # 2 Megabyte
TEST_CACHE_NAME = 'test_cache_name'
TEST_CACHE_PARTITION_FILE_FILENAME = 'test_cache_partition_file_filename'
TEST_CACHE_PARTITION_FILE_SIZE = 1 * 2 ** 20  # 1 Megabyte
TEST_CACHE_PARTITION_NAME = 'test_cache_partition_name'
TEST_CACHE_STORAGE_INSTANCE_PATH = 'mayan.apps.file_caching.tests.mixins.test_storage'
