from __future__ import unicode_literals

TEST_WEB_LINK_LABEL = 'test web link label'
TEST_WEB_LINK_LABEL_EDITED = 'test web link label edited'
TEST_WEB_LINK_TEMPLATE = 'http://www.example.com/document-{{ document.uuid }}'
