from __future__ import unicode_literals

TEST_CASE_GROUP_NAME = 'test case group'

TEST_CASE_SUPERUSER_EMAIL = 'test_case_superuser@example.com'
TEST_CASE_SUPERUSER_PASSWORD = 'test case superuser password'
TEST_CASE_SUPERUSER_USERNAME = 'test_case_superuser'

TEST_CASE_USER_EMAIL = 'test_case_user@example.com'
TEST_CASE_USER_PASSWORD = 'test case user password'
TEST_CASE_USER_USERNAME = 'test_case_user'

TEST_GROUP_NAME = 'test group'
TEST_GROUP_NAME_EDITED = 'test group edited'
TEST_GROUP_2_NAME = 'test group 2'
TEST_GROUP_2_NAME_EDITED = 'test group 2 edited'

TEST_USER_EMAIL = 'testuser@example.com'
TEST_USER_PASSWORD = 'test user password'
TEST_USER_PASSWORD_EDITED = 'test user password edited'
TEST_USER_USERNAME = 'test_user'
TEST_USER_USERNAME_EDITED = 'test_user_edited'

TEST_USER_2_EMAIL = 'testuser2@example.com'
TEST_USER_2_PASSWORD = 'test user 2 password'
TEST_USER_2_PASSWORD_EDITED = 'test user 2 password edited'
TEST_USER_2_USERNAME = 'test_user_2'
TEST_USER_2_USERNAME_EDITED = 'test_user_2_edited'
