from __future__ import absolute_import, unicode_literals

from mayan.apps.appearance.classes import Icon

icon_namespace_detail = Icon(driver_name='fontawesome', symbol='sliders-h')
icon_namespace_list = Icon(driver_name='fontawesome', symbol='sliders-h')
icon_setting_edit = Icon(driver_name='fontawesome', symbol='times')
